Skip to main contentCrate cloudiful_config
Source - ConfigSource
- FileType
- config_dir
- Resolve the per-user config directory for
app_name on the current OS. - config_path
- Resolve a config file path relative to the per-user config directory.
- read
- Read config from an explicit source.
- read_existing
- Read config from an existing TOML, JSON, or JSONC file.
- read_or_create_default
- Read config from a TOML, JSON, or JSONC file, creating the file with
T::default() when it does not already exist. - save
- Save the current config to a TOML or JSON file.
- save_inferred
- Save the current config by inferring the format from the file extension.